import fs from 'fs';
import path from 'path';
import bytes from 'bytes';
import rimraf from 'rimraf';
import webpack from 'webpack';
import gzipSize from 'gzip-size';

import getExtraConfig from './getExtraConfig';
import getWebpackConfig from './getWebpackConfig';
import compilerErrorHandle from './compilerErrorHandle';

import utils from './utils';

export default function runBuild() {
    const webpackConfig: webpack.Configuration = getWebpackConfig(getExtraConfig().webpack);

    utils.success('Creating an optimized production build...');
    // 删除build路径
    rimraf.sync(webpackConfig?.output?.path || '');

    webpack(webpackConfig, function (err: Error, stats: webpack.Stats) {
        stats?.toJson()?.assets?.filter(asset => {
            const filePath = path.join('dist', asset.name);
            const fileContents = fs.readFileSync(filePath);
            const size = gzipSize.sync(fileContents);
            utils.loggerPrefix(
                utils.chalk.green(`${filePath} ${size > 0
                    ? `${utils.chalk.cyan('===>')} ${utils.chalk.blue(bytes(size))}`
                    : ''
                    }`)
            );
        });

        utils.success('Compiled successfully!');
        compilerErrorHandle(stats, err);
    });
};
