import {PluginItem} from '@babel/core';
import {MockConfig} from './middleware/mock';
import {ProxyConfigMap, ProxyConfigArray} from 'webpack-dev-server';

import utils from './utils';
import paths from './paths';

interface RcbConfig {
    host?: string;
    port?: number;
    proxy?: ProxyConfigMap | ProxyConfigArray,
    mock?: MockConfig,
    babelPresets?: PluginItem[] | null,
    babelPlugins?: PluginItem[] | null
}

function getWebpackConfig() {
    let path: string = '';
    if (utils.isDev()) {
        path = paths.getResolvePath('webpack.config.dev.js');
    }

    if (utils.isProduction()) {
        path = paths.getResolvePath('webpack.config.prod.js');
    }

    path = paths.getResolvePath('webpack.config.js');

    try {
        return utils.requireModule(path);
    }
    catch (e) {
        return {};
    }
}

export function getRcbConfig(): RcbConfig {
    try {
        return utils.requireModule(paths.getResolvePath('rcb.config.js'));
    }
    catch (e) {
        return {};
    }
}

function getBabelConfig() {
    // TODO
    return {};
}

export default function getExtraConfig() {
    return {
        webpack: getWebpackConfig(),
        babel: getBabelConfig(),
        rcb: getRcbConfig()
    };
};
